==> nextcloud-app-spreed-1%3A10.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ar.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "ضيف",
    "You created the conversation" : "أنشأتَ المحادثة",
    "You left the call" : "لقد قمت بمغادرة المكالمة",
    "Click the button below to join." : "اضغط على الزر للانضمام.",
    "Open settings" : "فتح الإعدادات",
    "Messages" : "الرسائل",
    "Andorra" : "أندورا",
    "United Arab Emirates" : "الإمارات العربية المتحدة",
    "Afghanistan" : "أفغانستان",
    "Antigua and Barbuda" : "أنتيغوا وبربودا",
    "Anguilla" : "أنغيلا",
    "Albania" : "ألبانيا",
    "Armenia" : "أرمينيا",
    "Angola" : "أنغولا",
    "Antarctica" : "القارة القطبية الجنوبية",
    "Argentina" : "الأرجنتين",
    "American Samoa" : "ساموا الأمريكية",
    "Austria" : "النمسا",
    "Australia" : "أستراليا",
    "Aruba" : "أروبا",
    "Åland Islands" : "جزر آلاند",
    "Azerbaijan" : "أذربيجان",
    "Bosnia and Herzegovina" : "البوسنة والهرسك",
    "Barbados" : "بربادوس",
    "Bangladesh" : "بنغلاديش",
    "Belgium" : "بلجيكا",
    "Burkina Faso" : "بوركينا فاسو",
    "Bulgaria" : "بلغاريا",
    "Bahrain" : "البحرين",
    "Burundi" : "بوروندي",
    "Benin" : "البنين",
    "Saint Barthélemy" : "سانت بارتيليمي",
    "Bermuda" : "برمودا",
    "Brunei Darussalam" : "بروناي دار السلام",
    "Brazil" : "البرازيل",
    "Canada" : "كندا",
    "Cameroon" : "الكاميرون",
    "China" : "الصين",
    "Costa Rica" : "كوستاريكا",
    "Cuba" : "كوبا",
    "Cyprus" : "قبرص",
    "Germany" : "ألمانيا",
    "Djibouti" : "جيبوتي",
    "Denmark" : "الدانمارك",
    "Algeria" : "الجزائر",
    "Egypt" : "مصر",
    "Spain" : "إسبانيا",
    "Ethiopia" : "إثيوبيا",
    "Finland" : "فنلندا",
    "France" : "فرنسا",
    "Georgia" : "جيورجيا",
    "Ghana" : "غانا",
    "Greece" : "اليونان",
    "Hong Kong" : "هونج كونج",
    "Hungary" : "هنغاريا",
    "Indonesia" : "أندونيسيا",
    "Israel" : "الكيان الصهيوني",
    "India" : "الهند",
    "Iraq" : "العراق",
    "Iceland" : "ايسلندا",
    "Italy" : "إيطاليا",
    "Jamaica" : "جامايكا",
    "Jordan" : "الأردن",
    "Japan" : "اليابان",
    "Kenya" : "كينيا",
    "Kuwait" : "الكويت",
    "Lebanon" : "لبنان",
    "Liechtenstein" : "ليختنشتاين",
    "Sri Lanka" : "سيريلانكا",
    "Liberia" : "ليبيريا",
    "Lesotho" : "ليسوتو",
    "Lithuania" : "ليتوانيا",
    "Luxembourg" : "لوكسمبورغ",
    "Latvia" : "لاتفيا",
    "Libya" : "ليبيا",
    "Morocco" : "المغرب",
    "Madagascar" : "مدغشقر",
    "Mali" : "مالي",
    "Myanmar" : "ميانمار",
    "Mauritania" : "موريطانيا",
    "Malaysia" : "ماليزيا",
    "Niger" : "النيجر",
    "Nigeria" : "نيجيريا",
    "Norway" : "النرويج",
    "Oman" : "عمان",
    "Pakistan" : "باكستان",
    "Poland" : "بولونيا",
    "Portugal" : "البرتغال",
    "Qatar" : "قطر",
    "Romania" : "رومانيا",
    "Rwanda" : "رواندا",
    "Sudan" : "السودان",
    "Sweden" : "السويد",
    "Senegal" : "السنيغال",
    "Somalia" : "الصومال",
    "South Sudan" : "جنوب السودان",
    "Chad" : "تشاد",
    "Tunisia" : "تونس",
    "Turkey" : "تركيا",
    "Ukraine" : "أوكرانيا",
    "Uganda" : "أوغندا",
    "United States Minor Outlying Islands" : "جزر الولايات المتحدة البعيدة الصغرى",
    "United States of America" : "الولايات المتحدة الأمريكية",
    "Uruguay" : "أوروغواي",
    "Uzbekistan" : "أوزبكستان",
    "Holy See" : "الكرسي الرسولي دولة الفاتيكان",
    "Saint Vincent and the Grenadines" : "سانت فنسنت وجزر غرينادين",
    "Viet Nam" : "فييتنام",
    "Vanuatu" : "فانواتو",
    "Wallis and Futuna" : "جزر واليس وفوتونا",
    "Samoa" : "ساموا",
    "Yemen" : "اليمن",
    "Mayotte" : "مايوت",
    "South Africa" : "إفريقيا الجنوبية",
    "Zambia" : "زامبيا",
    "Zimbabwe" : "زيمبابوي",
    "Conversation not found" : "المحادثة غير موجودة",
    "Everyone" : "الجميع",
    "Save changes" : "حفظ التعديلات",
    "None" : "لا شيء",
    "User" : "المستخدم",
    "Disabled" : "معطّل",
    "Users" : "المستخدمين:",
    "Beta" : "تجريبي",
    "Name" : "الاسم",
    "Command" : "الأمر",
    "General settings" : "الإعدادات العامة",
    "All messages" : "كافة الرسائل",
    "Language" : "اللغة",
    "Country" : "البلد",
    "Status" : "الحالة",
    "Pending" : "معلّق",
    "Error" : "خطأ",
    "Blocked" : "محجوب",
    "Saved" : "تم الإحتفاظ به",
    "Add a new server" : "إضافة خادم جديد",
    "Test this server" : "جرّب هذا الخادم",
    "Copy link" : "انسخ الرابط",
    "Dismiss" : "تراجع",
    "Mute audio" : "كتم الصوت",
    "Disable video" : "تعطيل الفيديو",
    "Back" : "العودة",
    "You" : "أنت",
    "Drop your files to upload" : "افلت الملفات لرفعها",
    "Favorite" : "المفضلة",
    "Leave conversation" : "غادر المحادثة",
    "Delete conversation" : "احذف المحادثة",
    "Remove from favorites" : "إزالتها مِن المفضلة",
    "Add to favorites" : "أضفه إلى المفضلة",
    "Loading" : "Loading",
    "Groups" : "الفِرَق",
    "Settings" : "الإعدادات",
    "Password protect" : "حماية كلمة السر",
    "Close" : "إغلاق",
    "Conversation name" : "اسم المحادثة",
    "Camera" : "الكاميرا",
    "Reply" : "رد",
    "Remove" : "حذف",
    "Today" : "اليوم",
    "Yesterday" : "البارحة",
    "Send message" : "أرسل رسالة",
    "Enabled" : "مفعلة",
    "Save" : "حفظ",
    "Password" : "الكلمة السرية",
    "Login" : "الدخول",
    "Nickname" : "كنية.\nلقب.",
    "No results" : "دون أية نتيجة",
    "Add users or groups" : "Add users or groups",
    "Participants" : "المشاركون",
    "Chat" : "الدردشة",
    "Edit" : "تعديل",
    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
    "Search" : "البحث",
    "Rename conversation" : "إعادة تسمية المحادثة",
    "Share link" : "مشاركة الرابط",
    "Password protection" : "الحماية بكلمة السر",
    "Enter a password" : "إدخِل كلمة سرية",
    "Grid view" : "عرض شبكي",
    "Start a conversation" : "ابدأ محادثة",
    "Default" : "افتراضي",
    "The password is wrong. Try again." : "كلمة المرور خاطئة. حاول مرة أخرى.",
    "Join conversations at any time, anywhere, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز",
    "Android app" : "تطبيق الأندرويد",
    "iOS app" : "تطبيق آي أواس",
    "Projects" : "المشاريع",
    "Copy" : "أنسخ",
    "Copied!" : "تم نسخه !",
    "Not supported!" : "غير مدعوم!",
    "Press ⌘-C to copy." : "إضغط ⌘-C للنسخ",
    "Press Ctrl-C to copy." : "إضغط Ctrl-C للنسخ.",
    "Password required" : "كلمة السر مطلوبة",
    "Cancel" : "إلغاء",
    "Guests" : "الضيوف",
    "Change password" : "تعديل الكلمة السرية",
    "Set password" : "تعيين كلمة سرية",
    "Rename" : "إعادة التسمية",
    "Send" : "أرسل",
    "Share" : "شارك",
    "Error while sharing" : "حصل خطأ عند عملية المشاركة",
    "Favorited" : "المفضلة",
    "Join conversations at any time, any where, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز",
    "Contacts" : "المُراسِلون"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-app-spreed-1%3A10.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ar.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "ضيف",
    "You created the conversation" : "أنشأتَ المحادثة",
    "You left the call" : "لقد قمت بمغادرة المكالمة",
    "Click the button below to join." : "اضغط على الزر للانضمام.",
    "Open settings" : "فتح الإعدادات",
    "Messages" : "الرسائل",
    "Andorra" : "أندورا",
    "United Arab Emirates" : "الإمارات العربية المتحدة",
    "Afghanistan" : "أفغانستان",
    "Antigua and Barbuda" : "أنتيغوا وبربودا",
    "Anguilla" : "أنغيلا",
    "Albania" : "ألبانيا",
    "Armenia" : "أرمينيا",
    "Angola" : "أنغولا",
    "Antarctica" : "القارة القطبية الجنوبية",
    "Argentina" : "الأرجنتين",
    "American Samoa" : "ساموا الأمريكية",
    "Austria" : "النمسا",
    "Australia" : "أستراليا",
    "Aruba" : "أروبا",
    "Åland Islands" : "جزر آلاند",
    "Azerbaijan" : "أذربيجان",
    "Bosnia and Herzegovina" : "البوسنة والهرسك",
    "Barbados" : "بربادوس",
    "Bangladesh" : "بنغلاديش",
    "Belgium" : "بلجيكا",
    "Burkina Faso" : "بوركينا فاسو",
    "Bulgaria" : "بلغاريا",
    "Bahrain" : "البحرين",
    "Burundi" : "بوروندي",
    "Benin" : "البنين",
    "Saint Barthélemy" : "سانت بارتيليمي",
    "Bermuda" : "برمودا",
    "Brunei Darussalam" : "بروناي دار السلام",
    "Brazil" : "البرازيل",
    "Canada" : "كندا",
    "Cameroon" : "الكاميرون",
    "China" : "الصين",
    "Costa Rica" : "كوستاريكا",
    "Cuba" : "كوبا",
    "Cyprus" : "قبرص",
    "Germany" : "ألمانيا",
    "Djibouti" : "جيبوتي",
    "Denmark" : "الدانمارك",
    "Algeria" : "الجزائر",
    "Egypt" : "مصر",
    "Spain" : "إسبانيا",
    "Ethiopia" : "إثيوبيا",
    "Finland" : "فنلندا",
    "France" : "فرنسا",
    "Georgia" : "جيورجيا",
    "Ghana" : "غانا",
    "Greece" : "اليونان",
    "Hong Kong" : "هونج كونج",
    "Hungary" : "هنغاريا",
    "Indonesia" : "أندونيسيا",
    "Israel" : "الكيان الصهيوني",
    "India" : "الهند",
    "Iraq" : "العراق",
    "Iceland" : "ايسلندا",
    "Italy" : "إيطاليا",
    "Jamaica" : "جامايكا",
    "Jordan" : "الأردن",
    "Japan" : "اليابان",
    "Kenya" : "كينيا",
    "Kuwait" : "الكويت",
    "Lebanon" : "لبنان",
    "Liechtenstein" : "ليختنشتاين",
    "Sri Lanka" : "سيريلانكا",
    "Liberia" : "ليبيريا",
    "Lesotho" : "ليسوتو",
    "Lithuania" : "ليتوانيا",
    "Luxembourg" : "لوكسمبورغ",
    "Latvia" : "لاتفيا",
    "Libya" : "ليبيا",
    "Morocco" : "المغرب",
    "Madagascar" : "مدغشقر",
    "Mali" : "مالي",
    "Myanmar" : "ميانمار",
    "Mauritania" : "موريطانيا",
    "Malaysia" : "ماليزيا",
    "Niger" : "النيجر",
    "Nigeria" : "نيجيريا",
    "Norway" : "النرويج",
    "Oman" : "عمان",
    "Pakistan" : "باكستان",
    "Poland" : "بولونيا",
    "Portugal" : "البرتغال",
    "Qatar" : "قطر",
    "Romania" : "رومانيا",
    "Rwanda" : "رواندا",
    "Sudan" : "السودان",
    "Sweden" : "السويد",
    "Senegal" : "السنيغال",
    "Somalia" : "الصومال",
    "South Sudan" : "جنوب السودان",
    "Chad" : "تشاد",
    "Tunisia" : "تونس",
    "Turkey" : "تركيا",
    "Ukraine" : "أوكرانيا",
    "Uganda" : "أوغندا",
    "United States Minor Outlying Islands" : "جزر الولايات المتحدة البعيدة الصغرى",
    "United States of America" : "الولايات المتحدة الأمريكية",
    "Uruguay" : "أوروغواي",
    "Uzbekistan" : "أوزبكستان",
    "Holy See" : "الكرسي الرسولي دولة الفاتيكان",
    "Saint Vincent and the Grenadines" : "سانت فنسنت وجزر غرينادين",
    "Viet Nam" : "فييتنام",
    "Vanuatu" : "فانواتو",
    "Wallis and Futuna" : "جزر واليس وفوتونا",
    "Samoa" : "ساموا",
    "Yemen" : "اليمن",
    "Mayotte" : "مايوت",
    "South Africa" : "إفريقيا الجنوبية",
    "Zambia" : "زامبيا",
    "Zimbabwe" : "زيمبابوي",
    "Conversation not found" : "المحادثة غير موجودة",
    "Everyone" : "الجميع",
    "Save changes" : "حفظ التعديلات",
    "None" : "لا شيء",
    "User" : "المستخدم",
    "Disabled" : "معطّل",
    "Users" : "المستخدمين:",
    "Beta" : "تجريبي",
    "Name" : "الاسم",
    "Command" : "الأمر",
    "General settings" : "الإعدادات العامة",
    "All messages" : "كافة الرسائل",
    "Off" : "إيقاف",
    "Language" : "اللغة",
    "Country" : "البلد",
    "Status" : "الحالة",
    "Pending" : "معلّق",
    "Error" : "خطأ",
    "Blocked" : "محجوب",
    "Saved" : "تم الإحتفاظ به",
    "Add a new server" : "إضافة خادم جديد",
    "Test this server" : "جرّب هذا الخادم",
    "Copy link" : "انسخ الرابط",
    "Dismiss" : "تراجع",
    "Mute audio" : "كتم الصوت",
    "Disable video" : "تعطيل الفيديو",
    "You" : "أنت",
    "Drop your files to upload" : "افلت الملفات لرفعها",
    "Favorite" : "المفضلة",
    "Leave conversation" : "غادر المحادثة",
    "Delete conversation" : "احذف المحادثة",
    "Remove from favorites" : "إزالتها مِن المفضلة",
    "Add to favorites" : "أضفه إلى المفضلة",
    "Loading" : "Loading",
    "Groups" : "الفِرَق",
    "Settings" : "الإعدادات",
    "Password protect" : "حماية كلمة السر",
    "Back" : "العودة",
    "Close" : "إغلاق",
    "Conversation name" : "اسم المحادثة",
    "Camera" : "الكاميرا",
    "Reply" : "رد",
    "Remove" : "حذف",
    "Today" : "اليوم",
    "Yesterday" : "البارحة",
    "Send message" : "أرسل رسالة",
    "Enabled" : "مفعلة",
    "Save" : "حفظ",
    "Password" : "الكلمة السرية",
    "Login" : "الدخول",
    "Nickname" : "كنية.\nلقب.",
    "No results" : "دون أية نتيجة",
    "Add users or groups" : "Add users or groups",
    "Participants" : "المشاركون",
    "Chat" : "الدردشة",
    "Edit" : "تعديل",
    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
    "Search" : "البحث",
    "Rename conversation" : "إعادة تسمية المحادثة",
    "Share link" : "مشاركة الرابط",
    "Password protection" : "الحماية بكلمة السر",
    "Enter a password" : "إدخِل كلمة سرية",
    "Grid view" : "عرض شبكي",
    "Send" : "أرسل",
    "Start a conversation" : "ابدأ محادثة",
    "Default" : "افتراضي",
    "The password is wrong. Try again." : "كلمة المرور خاطئة. حاول مرة أخرى.",
    "Join conversations at any time, anywhere, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز",
    "Android app" : "تطبيق الأندرويد",
    "iOS app" : "تطبيق آي أواس",
    "Contacts" : "المُراسِلون",
    "Guests" : "الضيوف",
    "Projects" : "المشاريع",
    "Password required" : "كلمة السر مطلوبة",
    "Cancel" : "إلغاء"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
